µRaiden

### Transfer of TKN requested

#### µRaiden payment channel demo

##### 1. Click Buy to get TKN tokens in exchange for Ropsten Testnet ETH.

##### 2. Click Deposit to open a channel with the selected deposit of TKN.

##### 3. For each transfer, sign the balance proof to access the content.

Account
Balance

##### No accounts found!

##### You may need to unlock your account on your Web3 provider. (Metamask/Mist/Parity)

##### Invalid contract response!

##### Web3 provider failed to get proper contract response.
Please, check your provider is in the right network and synced!

##### Loading channel

##### A channel was found for this address.

Status
opened closed settled invalid
Remaining Balance
TKN

##### Press the Sign button to authorize the transfer.

##### No channel was found registered for this account on this website.

##### In order to proceed...

1. Make a desired token deposit to open a channel with this site.
2. For each transfer, sign a message confirming the balance with the new transferred amount.
   PS: the balance is the cumulative sum of all previous payments and current one. It may also be shown multiplied by as many decimals as token decimals (up to 18).

##### The transactions are being processed.

##### Please authorize with your Ethereum client.

##### Insufficient deposited funds on this channel.

Current Deposit
TKN
Remaining Balance
TKN

##### In order to proceed, deposit at least TKN tokens